@@ -29,15 +29,19 @@ const SecretVariableDefaultsToFile = true
 const (
 	DefaultTraceOutputLimit = 4 * 1024 * 1024 // in bytes
 	DefaultTracePatchLimit  = 1024 * 1024     // in bytes
-	DefaultUpdateInterval   = 3 * time.Second
-	MaxUpdateInterval       = 3 * time.Minute
-	TraceForceSendInterval  = 30 * time.Second
+
+	DefaultUpdateInterval = 3 * time.Second
+	MaxUpdateInterval     = 15 * time.Minute
+
+	MinTraceForceSendInterval              = 30 * time.Second
+	MaxTraceForceSendInterval              = 30 * time.Minute
+	TraceForceSendUpdateIntervalMultiplier = 4
 )
 
 var PreparationRetryInterval = 3 * time.Second
 
 const (
-	TestAlpineImage       = "alpine:3.12.0"
+	TestAlpineImage       = "alpine:3.13.6"
 	TestWindowsImage      = "mcr.microsoft.com/windows/servercore:%s"
 	TestPwshImage         = "mcr.microsoft.com/powershell:7.1.1-alpine-3.12-20210125"
 	TestAlpineNoRootImage = "registry.gitlab.com/gitlab-org/gitlab-runner/alpine-no-root:latest"
