@@ -7,19 +7,22 @@ import (
 )
 
 const (
-	CmdDisableDelayedErrorLevelExpansion        string = "FF_CMD_DISABLE_DELAYED_ERROR_LEVEL_EXPANSION"
-	NetworkPerBuild                             string = "FF_NETWORK_PER_BUILD"
-	UseLegacyKubernetesExecutionStrategy        string = "FF_USE_LEGACY_KUBERNETES_EXECUTION_STRATEGY"
-	UseDirectDownload                           string = "FF_USE_DIRECT_DOWNLOAD"
-	SkipNoOpBuildStages                         string = "FF_SKIP_NOOP_BUILD_STAGES"
-	UseFastzip                                  string = "FF_USE_FASTZIP"
-	GitLabRegistryHelperImage                   string = "FF_GITLAB_REGISTRY_HELPER_IMAGE"
-	DisableUmaskForDockerExecutor               string = "FF_DISABLE_UMASK_FOR_DOCKER_EXECUTOR"
-	EnableBashExitCodeCheck                     string = "FF_ENABLE_BASH_EXIT_CODE_CHECK"
-	UseWindowsLegacyProcessStrategy             string = "FF_USE_WINDOWS_LEGACY_PROCESS_STRATEGY"
-	SkipDockerMachineProvisionOnCreationFailure string = "FF_SKIP_DOCKER_MACHINE_PROVISION_ON_CREATION_FAILURE"
-	UseNewEvalStrategy                          string = "FF_USE_NEW_BASH_EVAL_STRATEGY"
-	UsePowershellPathResolver                   string = "FF_USE_POWERSHELL_PATH_RESOLVER"
+	CmdDisableDelayedErrorLevelExpansion string = "FF_CMD_DISABLE_DELAYED_ERROR_LEVEL_EXPANSION"
+	NetworkPerBuild                      string = "FF_NETWORK_PER_BUILD"
+	UseLegacyKubernetesExecutionStrategy string = "FF_USE_LEGACY_KUBERNETES_EXECUTION_STRATEGY"
+	UseDirectDownload                    string = "FF_USE_DIRECT_DOWNLOAD"
+	SkipNoOpBuildStages                  string = "FF_SKIP_NOOP_BUILD_STAGES"
+	UseFastzip                           string = "FF_USE_FASTZIP"
+	GitLabRegistryHelperImage            string = "FF_GITLAB_REGISTRY_HELPER_IMAGE"
+	DisableUmaskForDockerExecutor        string = "FF_DISABLE_UMASK_FOR_DOCKER_EXECUTOR"
+	EnableBashExitCodeCheck              string = "FF_ENABLE_BASH_EXIT_CODE_CHECK"
+	UseWindowsLegacyProcessStrategy      string = "FF_USE_WINDOWS_LEGACY_PROCESS_STRATEGY"
+	UseNewEvalStrategy                   string = "FF_USE_NEW_BASH_EVAL_STRATEGY"
+	UsePowershellPathResolver            string = "FF_USE_POWERSHELL_PATH_RESOLVER"
+	UseDynamicTraceForceSendInterval     string = "FF_USE_DYNAMIC_TRACE_FORCE_SEND_INTERVAL"
+	ScriptSections                       string = "FF_SCRIPT_SECTIONS"
+	UseNewShellEscape                    string = "FF_USE_NEW_SHELL_ESCAPE"
+	EnableJobCleanup                     string = "FF_ENABLE_JOB_CLEANUP"
 )
 
 type FeatureFlag struct {
@@ -124,16 +127,6 @@ var flags = []FeatureFlag{
 			"process setup is used. To successfully and gracefully drain a Windows Runner, this feature flag should" +
 			"be set to `false`.",
 	},
-	{
-		Name:            SkipDockerMachineProvisionOnCreationFailure,
-		DefaultValue:    true,
-		Deprecated:      false,
-		ToBeRemovedWith: "",
-		Description: "With the `docker+machine` executor, when a machine is " +
-			"not created, `docker-machine provision` runs for X amount of times. When " +
-			"this feature flag is set to `true`, it skips `docker-machine provision`, " +
-			"removes the machine, and creates another machine instead.",
-	},
 	{
 		Name:            UseNewEvalStrategy,
 		DefaultValue:    false,
@@ -150,6 +143,38 @@ var flags = []FeatureFlag{
 		Description: "When enabled, Powershell resolves pathnames rather than Runner using OS-specific filepath " +
 			"functions that are specific to where Runner is hosted.",
 	},
+	{
+		Name:            UseDynamicTraceForceSendInterval,
+		DefaultValue:    false,
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description: "When enabled, the trace force send interval is dynamically adjusted based on the trace " +
+			"update interval.",
+	},
+	{
+		Name:            ScriptSections,
+		DefaultValue:    false,
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description: "When enabled, each script line from the `.gitlab-ci.yml` file will be in a collapsible " +
+			"section in the job output and show the duration of each line.",
+	},
+	{
+		Name:            UseNewShellEscape,
+		DefaultValue:    false,
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description:     "When enabled, a faster implementation of shell escape is used.",
+	},
+	{
+		Name:            EnableJobCleanup,
+		DefaultValue:    false,
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description: "When enabled, the project directory will be cleaned up at the end of the build. " +
+			"If `GIT_CLONE` is used, the whole project directory will be deleted. If `GIT_FETCH` is used, " +
+			"a series of Git `clean` commands will be issued.",
+	},
 }
 
 func GetAll() []FeatureFlag {
