@@ -11,9 +11,12 @@ import (
 
 	"gitlab.com/gitlab-org/gitlab-runner/cache"
 	"gitlab.com/gitlab-org/gitlab-runner/common"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/tls"
 )
 
+var errUnknownGitStrategy = errors.New("unknown GIT_STRATEGY")
+
 type AbstractShell struct {
 }
 
@@ -52,6 +55,10 @@ func (b *AbstractShell) cacheFile(build *common.Build, userKey string) (key, fil
 	}
 
 	file = path.Join(build.CacheDir, key, "cache.zip")
+	if build.IsFeatureFlagOn(featureflags.UsePowershellPathResolver) {
+		return key, file
+	}
+
 	file, err := filepath.Rel(build.BuildDir, file)
 	if err != nil {
 		return "", ""
@@ -212,7 +219,7 @@ func (b *AbstractShell) writeGetSourcesScript(w ShellWriter, info common.ShellSc
 	}
 
 	if info.PreCloneScript != "" && info.Build.GetGitStrategy() != common.GitNone {
-		b.writeCommands(w, info.PreCloneScript)
+		b.writeCommands(w, info, "pre_clone_script", info.PreCloneScript)
 	}
 
 	if err := b.writeCloneFetchCmds(w, info); err != nil {
@@ -316,7 +323,7 @@ func (b *AbstractShell) handleGetSourcesStrategy(w ShellWriter, build *common.Bu
 		w.Noticef("Skipping Git repository setup")
 		w.MkDir(projectDir)
 	default:
-		return errors.New("unknown GIT_STRATEGY")
+		return errUnknownGitStrategy
 	}
 
 	return nil
@@ -449,6 +456,8 @@ func (b *AbstractShell) writeSubmoduleUpdateCmd(w ShellWriter, build *common.Bui
 	w.Command("git", append(foreachArgs, "git clean -ffxd")...)
 	w.Command("git", append(foreachArgs, "git reset --hard")...)
 	w.Command("git", updateArgs...)
+	// Clean changed files in sub-submodules
+	w.Command("git", append(foreachArgs, "git clean -ffxd")...)
 
 	if !build.IsLFSSmudgeDisabled() {
 		w.IfCmd("git", "lfs", "version")
@@ -486,9 +495,16 @@ func (b *AbstractShell) writeDownloadArtifactsScript(w ShellWriter, info common.
 }
 
 // Write the given string of commands using the provided ShellWriter object.
-func (b *AbstractShell) writeCommands(w ShellWriter, commands ...string) {
-	for _, command := range commands {
+func (b *AbstractShell) writeCommands(w ShellWriter, info common.ShellScriptInfo, prefix string, commands ...string) {
+	for i, command := range commands {
 		command = strings.TrimSpace(command)
+
+		if info.Build.IsFeatureFlagOn(featureflags.ScriptSections) &&
+			info.Build.JobResponse.Features.TraceSections {
+			b.writeCommandWithSection(w, fmt.Sprintf("%s_%d", prefix, i), command)
+			continue
+		}
+
 		if command != "" {
 			lines := strings.SplitN(command, "\n", 2)
 			if len(lines) > 1 {
@@ -505,6 +521,23 @@ func (b *AbstractShell) writeCommands(w ShellWriter, commands ...string) {
 	}
 }
 
+func (b *AbstractShell) writeCommandWithSection(w ShellWriter, sectionName, command string) {
+	if command == "" {
+		w.EmptyLine()
+	}
+
+	lines := strings.SplitN(command, "\n", 2)
+	if len(lines) > 1 {
+		w.SectionStart(sectionName, fmt.Sprintf("$ %s # collapsed multi-line command", lines[0]))
+	} else {
+		w.SectionStart(sectionName, fmt.Sprintf("$ %s", lines[0]))
+	}
+
+	w.Line(command)
+	w.CheckForErrors()
+	w.SectionEnd(sectionName)
+}
+
 func (b *AbstractShell) writeUserScript(
 	w ShellWriter,
 	info common.ShellScriptInfo,
@@ -526,13 +559,13 @@ func (b *AbstractShell) writeUserScript(
 	b.writeCdBuildDir(w, info)
 
 	if info.PreBuildScript != "" {
-		b.writeCommands(w, info.PreBuildScript)
+		b.writeCommands(w, info, "pre_build_script", info.PreBuildScript)
 	}
 
-	b.writeCommands(w, scriptStep.Script...)
+	b.writeCommands(w, info, "script_step", scriptStep.Script...)
 
 	if info.PostBuildScript != "" {
-		b.writeCommands(w, info.PostBuildScript)
+		b.writeCommands(w, info, "post_build_script", info.PostBuildScript)
 	}
 
 	return nil
@@ -770,7 +803,9 @@ func (b *AbstractShell) writeAfterScript(w ShellWriter, info common.ShellScriptI
 	b.writeCdBuildDir(w, info)
 
 	w.Noticef("Running after script...")
-	b.writeCommands(w, afterScriptStep.Script...)
+
+	b.writeCommands(w, info, "after_script_step", afterScriptStep.Script...)
+
 	return nil
 }
 
@@ -790,25 +825,75 @@ func (b *AbstractShell) writeArchiveCacheOnFailureScript(w ShellWriter, info com
 	return b.cacheArchiver(w, info, false)
 }
 
-func (b *AbstractShell) writeCleanupFileVariablesScript(w ShellWriter, info common.ShellScriptInfo) error {
-	skipCleanupFileVariables := true
+func (b *AbstractShell) writeCleanupScript(w ShellWriter, info common.ShellScriptInfo) error {
+	skipCleanupStage := true
 
 	for _, variable := range info.Build.GetAllVariables() {
 		if !variable.File {
 			continue
 		}
 
-		skipCleanupFileVariables = false
+		skipCleanupStage = false
 		w.RmFile(w.TmpFile(variable.Key))
 	}
 
-	if skipCleanupFileVariables {
+	if info.Build.IsFeatureFlagOn(featureflags.EnableJobCleanup) {
+		skipCleanupStage = false
+
+		if err := b.writeCleanupBuildDirectoryScript(w, info); err != nil {
+			return err
+		}
+	}
+
+	if skipCleanupStage {
 		return common.ErrSkipBuildStage
 	}
 
 	return nil
 }
 
+func (b *AbstractShell) writeCleanupBuildDirectoryScript(w ShellWriter, info common.ShellScriptInfo) error {
+	switch info.Build.GetGitStrategy() {
+	case common.GitClone:
+		w.RmDir(info.Build.FullProjectDir())
+	case common.GitFetch:
+		b.writeCdBuildDir(w, info)
+
+		var cleanArgs []string
+		cleanFlags := info.Build.GetGitCleanFlags()
+		if len(cleanFlags) > 0 {
+			cleanArgs = append([]string{"clean"}, cleanFlags...)
+			w.Command("git", cleanArgs...)
+		}
+
+		resetArgs := []string{"reset", "--hard"}
+		w.Command("git", resetArgs...)
+
+		if info.Build.GetSubmoduleStrategy() == common.SubmoduleNormal ||
+			info.Build.GetSubmoduleStrategy() == common.SubmoduleRecursive {
+			submoduleArgs := []string{"submodule", "foreach"}
+
+			if info.Build.GetSubmoduleStrategy() == common.SubmoduleRecursive {
+				submoduleArgs = append(submoduleArgs, "--recursive")
+			}
+
+			if len(cleanFlags) > 0 {
+				submoduleCleanArgs := append(submoduleArgs, append([]string{"git"}, cleanArgs...)...)
+				w.Command("git", submoduleCleanArgs...)
+			}
+
+			submoduleResetArgs := append(submoduleArgs, append([]string{"git"}, resetArgs...)...)
+			w.Command("git", submoduleResetArgs...)
+		}
+	case common.GitNone:
+		w.Noticef("Skipping build directory cleanup step")
+	default:
+		return errUnknownGitStrategy
+	}
+
+	return nil
+}
+
 func (b *AbstractShell) writeScript(w ShellWriter, buildStage common.BuildStage, info common.ShellScriptInfo) error {
 	methods := map[common.BuildStage]func(ShellWriter, common.ShellScriptInfo) error{
 		common.BuildStagePrepare:                  b.writePrepareScript,
@@ -820,7 +905,7 @@ func (b *AbstractShell) writeScript(w ShellWriter, buildStage common.BuildStage,
 		common.BuildStageArchiveOnFailureCache:    b.writeArchiveCacheOnFailureScript,
 		common.BuildStageUploadOnSuccessArtifacts: b.writeUploadArtifactsOnSuccessScript,
 		common.BuildStageUploadOnFailureArtifacts: b.writeUploadArtifactsOnFailureScript,
-		common.BuildStageCleanupFileVariables:     b.writeCleanupFileVariablesScript,
+		common.BuildStageCleanup:                  b.writeCleanupScript,
 	}
 
 	fn, ok := methods[buildStage]
